diff --git a/tests/TestSuite_pvp_multi_paths_virtio_single_core_performance.py b/tests/TestSuite_pvp_multi_paths_virtio_single_core_performance.py
index fa7940c6..f88d037f 100644
--- a/tests/TestSuite_pvp_multi_paths_virtio_single_core_performance.py
+++ b/tests/TestSuite_pvp_multi_paths_virtio_single_core_performance.py
@@ -302,7 +302,7 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
 
     def test_perf_virtio_single_core_virtio11_mergeable(self):
         """
-        performance for Vhost PVP virtio 1.1 Mergeable Path.
+        Case 1:performance for Vhost PVP virtio 1.1 mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -314,16 +314,16 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1_mergeable on")
+        self.send_and_verify("virtio1.1_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_virtio_single_core_virtio11_normal(self):
+    def test_perf_virtio_single_core_virtio11_non_mergeable(self):
         """
         performance for Vhost PVP virtio1.1 Normal Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -335,7 +335,7 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1_normal")
+        self.send_and_verify("virtio1.1_non_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -344,7 +344,7 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
 
     def test_perf_virtio_single_core_virtio11_inorder_mergeable(self):
         """
-        performance for Vhost PVP virtio 1.1 inorder  Mergeable Path.
+        Case 8:performance for Vhost PVP virtio 1.1 inorder  mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -356,16 +356,16 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1_inorder_mergeable on")
+        self.send_and_verify("virtio1.1_inorder_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_virtio_single_core_virtio11_inorder_normal(self):
+    def test_perf_virtio_single_core_virtio11_inorder_non_mergeable(self):
         """
         performance for Vhost PVP virtio1.1 inorder Normal Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -377,7 +377,7 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1_inorder_normal")
+        self.send_and_verify("virtio1.1_inorder_non_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -386,7 +386,7 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
 
     def test_perf_virtio_single_core_virtio11_vectorized(self):
         """
-        performance for Vhost PVP virtio1.1 vectorized Path.
+        Case 10:performance for Vhost PVP virtio1.1 vectorized Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -398,7 +398,7 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1_inorder_normal")
+        self.send_and_verify("virtio1.1_vectorized")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -407,7 +407,7 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
 
     def test_perf_virtio_single_core_inorder_mergeable(self):
         """
-        performance for Vhost PVP In_order mergeable Path.
+        Case 3:performance for Vhost PVP in_order mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -419,16 +419,16 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("inoder mergeable on")
+        self.send_and_verify("virtio1.0_inorder_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_virtio_single_core_inorder_normal(self):
+    def test_perf_virtio_single_core_inorder_non_mergeable(self):
         """
         performance for Vhost PVP In_order normal Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -440,7 +440,7 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("inoder mergeable off")
+        self.send_and_verify("virtio1.0_inorder_non_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -449,7 +449,7 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
 
     def test_perf_virtio_single_core_mergeable(self):
         """
-        performance for Vhost PVP Mergeable Path.
+        Case 5:performance for Vhost PVP mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -461,16 +461,16 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virito mergeable")
+        self.send_and_verify("virtio1.0_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_virtio_single_core_normal(self):
+    def test_perf_virtio_single_core_non_mergeable(self):
         """
         performance for Vhost PVP Normal Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -482,16 +482,16 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virito normal")
+        self.send_and_verify("virito1.0_non_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_virtio_single_core_vector_rx(self):
+    def test_perf_virtio_single_core_vectorized_rx(self):
         """
         performance for Vhost PVP Vector Path
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -503,7 +503,7 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio vector rx")
+        self.send_and_verify("virtio1.0_vectorized_rx")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -314,16 +314,16 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         """
-        performance for Vhost PVP virtio1.1 Normal Path.
+        Case 2:performance for Vhost PVP virtio1.1 non-mergeable Path.
         """
         self.test_target = self.running_case
@@ -356,16 +356,16 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         """
-        performance for Vhost PVP virtio1.1 inorder Normal Path.
+        Case 9:performance for Vhost PVP virtio1.1 inorder non-mergeable Path.
         """
         self.test_target = self.running_case
@@ -419,16 +419,16 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         """
-        performance for Vhost PVP In_order normal Path.
+        Case 4:performance for Vhost PVP in_order non-mergeable Path.
         """
         self.test_target = self.running_case
@@ -461,16 +461,16 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         """
-        performance for Vhost PVP Normal Path.
+        Case 6:performance for Vhost PVP non-mergeable Path.
         """
         self.test_target = self.running_case
@@ -482,16 +482,16 @@ class TestPVPMultiPathsVirtioSingleCorePerformance(TestCase):
         """
-        performance for Vhost PVP Vector Path
+        Case 7:performance for Vhost PVP vectorized Path
         """
         self.test_target = self.running_case
